# Mangandi - Python Package

Welcome to the Mangandi python package repository! 🐍

## Overview
Mangandi is a super cool python package that allows you to easily work with videos and images. It provides powerful tools for image and video manipulation in Python.

## Installation
You can install Mangandi via PyPI. Simply run:

```pip install Mangandi```

## Support
Join our Telegram support group [Support](https://t.me/XBOTSUPPORTS) for any help or queries related to Mangandi.

# Usage 

```

from Mangandi import ImageUploader

k = "/path/to/your/file.jpg"
up = ImageUploader(k)
link = up.upload()
print(f"Image uploaded! {link}")
```


# Sample pyrogram code

```
from Mangandi import ImageUploader

k = await message.reply_to_message.download()
up = ImageUploader(k)
link = up.upload()
print(f"Image uploaded! {link}")
```

 
